@@ -68,15 +68,17 @@ struct cmd_node *commands_new(
 	int(*execute)(struct lldpctl_conn_t*, struct writer*,
 	    struct cmd_env*, void *),
 	void *);
+struct cmd_node* commands_privileged(struct cmd_node *);
+struct cmd_node* commands_hidden(struct cmd_node *);
 void commands_free(struct cmd_node *);
 const char *cmdenv_arg(struct cmd_env*);
 const char *cmdenv_get(struct cmd_env*, const char*);
 int cmdenv_put(struct cmd_env*, const char*, const char*);
 int cmdenv_pop(struct cmd_env*, int);
 int commands_execute(struct lldpctl_conn_t *, struct writer *,
-    struct cmd_node *, int argc, const char **argv);
-char *commands_complete(struct cmd_node *, int argc, const char **argv,
-    int all);
+    struct cmd_node *, int, const char **, int);
+char *commands_complete(struct cmd_node *, int, const char **,
+    int, int);
 /* helpers */
 int cmd_check_no_env(struct cmd_env *, void *);
 int cmd_check_env(struct cmd_env *, void *);
@@ -97,6 +99,7 @@ int cmd_store_something_env_value_and_pop2(const char *, struct cmd_env *,
 lldpctl_atom_t* cmd_iterate_on_interfaces(struct lldpctl_conn_t *,
     struct cmd_env *);
 void cmd_restrict_ports(struct cmd_node *);
+void cmd_restrict_protocol(struct cmd_node *);
 
 /* misc.c */
 int contains(const char *, const char *);
@@ -109,7 +112,7 @@ char*  totag(const char *);
 void display_interfaces(lldpctl_conn_t *, struct writer *,
     struct cmd_env *, int, int);
 void display_interface(lldpctl_conn_t *, struct writer *, int,
-    lldpctl_atom_t *, lldpctl_atom_t *, int);
+    lldpctl_atom_t *, lldpctl_atom_t *, int, int);
 void display_configuration(lldpctl_conn_t *, struct writer *);
 void display_interfaces_stats(lldpctl_conn_t *, struct writer *,
     struct cmd_env *);
