@@ -16,6 +16,7 @@
  */
 
 #include "client.h"
+#include <string.h>
 
 /**
  * Show neighbors.
@@ -108,10 +109,31 @@ watchcb(lldpctl_conn_t *conn,
 	struct cmd_env *env = wa->env;
 	struct writer *w = wa->w;
 	const char *interfaces = cmdenv_get(env, "ports");
+	const char *proto_str;
+	int protocol = LLDPD_MODE_MAX;
+
 	if (interfaces && !contains(interfaces, lldpctl_atom_get_str(interface,
 		    lldpctl_k_interface_name)))
 		return;
 
+	/* user might have specified protocol to filter display results */
+	proto_str = cmdenv_get(env, "protocol");
+
+	if (proto_str) {
+		log_debug("display", "filter protocol: %s ", proto_str);
+
+		protocol = 0;	/* unsupported */
+		for (lldpctl_map_t *protocol_map =
+			 lldpctl_key_get_map(lldpctl_k_port_protocol);
+		     protocol_map->string;
+		     protocol_map++) {
+			if (!strcasecmp(proto_str, protocol_map->string)) {
+				protocol = protocol_map->value;
+				break;
+			}
+		}
+	}
+
 	switch (type) {
 	case lldpctl_c_deleted:
 		tag_start(w, "lldp-deleted", "LLDP neighbor deleted");
@@ -127,7 +149,7 @@ watchcb(lldpctl_conn_t *conn,
 	display_interface(conn, w, 1, interface, neighbor,
 	    cmdenv_get(env, "summary")?DISPLAY_BRIEF:
 	    cmdenv_get(env, "detailed")?DISPLAY_DETAILS:
-	    DISPLAY_NORMAL);
+	    DISPLAY_NORMAL, protocol);
 	tag_end(w);
 }
 
@@ -185,6 +207,9 @@ register_common_commands(struct cmd_node *root)
 
 	/* Some specific port */
 	cmd_restrict_ports(root);
+
+	/* Specific protocol */
+	cmd_restrict_protocol(root);
 }
 
 /**
