@@ -288,8 +288,8 @@ interfaces_helper_vlan(struct lldpd *cfg,
 }
 #endif
 
-/* Fill out chassis ID if not already done. This handler is special
-   because we will only handle interfaces that are already handled. */
+/* Fill out chassis ID if not already done. Only physical interfaces are
+ * considered. */
 void
 interfaces_helper_chassis(struct lldpd *cfg,
     struct interfaces_device_list *interfaces)
@@ -298,22 +298,24 @@ interfaces_helper_chassis(struct lldpd *cfg,
 	struct lldpd_hardware *hardware;
 	char *name = NULL;
 
-	LOCAL_CHASSIS(cfg)->c_cap_enabled &= ~(LLDP_CAP_BRIDGE | LLDP_CAP_WLAN);
+	LOCAL_CHASSIS(cfg)->c_cap_enabled &=
+			    ~(LLDP_CAP_BRIDGE | LLDP_CAP_WLAN | LLDP_CAP_STATION);
 	TAILQ_FOREACH(iface, interfaces, next) {
 		if (iface->type & IFACE_BRIDGE_T)
 			LOCAL_CHASSIS(cfg)->c_cap_enabled |= LLDP_CAP_BRIDGE;
 		if (iface->type & IFACE_WIRELESS_T)
 			LOCAL_CHASSIS(cfg)->c_cap_enabled |= LLDP_CAP_WLAN;
 	}
-	if (LOCAL_CHASSIS(cfg)->c_cap_enabled == 0)
-		LOCAL_CHASSIS(cfg)->c_cap_enabled = LLDP_CAP_STATION;
+	if ((LOCAL_CHASSIS(cfg)->c_cap_available & LLDP_CAP_STATION) &&
+		(LOCAL_CHASSIS(cfg)->c_cap_enabled == 0))
+	    LOCAL_CHASSIS(cfg)->c_cap_enabled = LLDP_CAP_STATION;
 
 	if (LOCAL_CHASSIS(cfg)->c_id != NULL &&
 	    LOCAL_CHASSIS(cfg)->c_id_subtype == LLDP_CHASSISID_SUBTYPE_LLADDR)
 		return;		/* We already have one */
 
 	TAILQ_FOREACH(iface, interfaces, next) {
-		if (iface->flags) continue;
+		if (!(iface->type & IFACE_PHYSICAL_T)) continue;
 		if (cfg->g_config.c_cid_pattern &&
 		    !pattern_match(iface->name, cfg->g_config.c_cid_pattern, 0)) continue;
 
