@@ -208,7 +208,7 @@ lldpd_hardware_cleanup(struct lldpd *cfg, struct lldpd_hardware *hardware)
 	log_debug("alloc", "cleanup hardware port %s", hardware->h_ifname);
 
 	lldpd_port_cleanup(&hardware->h_lport, 1);
-	if (hardware->h_ops->cleanup)
+	if (hardware->h_ops && hardware->h_ops->cleanup)
 		hardware->h_ops->cleanup(cfg, hardware);
 	levent_hardware_release(hardware);
 	free(hardware);
@@ -718,10 +718,15 @@ lldpd_get_os_release() {
 	char *key, *val;
 	char *ptr1 = release;
 
-	FILE *fp = fopen("/etc/os-release", "r");
 	log_debug("localchassis", "grab OS release");
+	FILE *fp = fopen("/etc/os-release", "r");
 	if (!fp) {
-		log_info("localchassis", "could not open /etc/os-release");
+		log_debug("localchassis", "could not open /etc/os-release");
+		fp = fopen("/usr/lib/os-release", "r");
+	}
+	if (!fp) {
+		log_info("localchassis",
+		    "could not open either /etc/os-release or /usr/lib/os-release");
 		return NULL;
 	}
 
@@ -975,6 +980,10 @@ static int
 lldpd_routing_enabled(struct lldpd *cfg)
 {
 	int routing;
+
+	if ((LOCAL_CHASSIS(cfg)->c_cap_available & LLDP_CAP_ROUTER) == 0)
+		return 0;
+
 	if ((routing = interfaces_routing_enabled(cfg)) == -1) {
 		log_debug("localchassis", "unable to check if routing is enabled");
 		return 0;
@@ -1043,7 +1052,8 @@ lldpd_update_localchassis(struct lldpd *cfg)
 	else
 		LOCAL_CHASSIS(cfg)->c_med_sw = strdup("Unknown");
 #endif
-	if (LOCAL_CHASSIS(cfg)->c_cap_enabled == 0)
+	if ((LOCAL_CHASSIS(cfg)->c_cap_available & LLDP_CAP_STATION) &&
+		(LOCAL_CHASSIS(cfg)->c_cap_enabled == 0))
 		LOCAL_CHASSIS(cfg)->c_cap_enabled = LLDP_CAP_STATION;
 
 	/* Set chassis ID if needed. This is only done if chassis ID
@@ -1339,15 +1349,31 @@ lldpd_main(int argc, char *argv[], char *envp[])
 			receiveonly = 1;
 			break;
 		case 'm':
+			if (mgmtp) {
+				fprintf(stderr, "-m can only be used once\n");
+				usage();
+			}
 			mgmtp = optarg;
 			break;
 		case 'u':
+			if (ctlname) {
+				fprintf(stderr, "-u can only be used once\n");
+				usage();
+			}
 			ctlname = optarg;
 			break;
 		case 'I':
+			if (interfaces) {
+				fprintf(stderr, "-I can only be used once\n");
+				usage();
+			}
 			interfaces = optarg;
 			break;
 		case 'C':
+			if (cidp) {
+				fprintf(stderr, "-C can only be used once\n");
+				usage();
+			}
 			cidp = optarg;
 			break;
 		case 'L':
@@ -1380,6 +1406,10 @@ lldpd_main(int argc, char *argv[], char *envp[])
 			snmp = 1;
 			break;
 		case 'X':
+			if (agentx) {
+				fprintf(stderr, "-X can only be used once\n");
+				usage();
+			}
 			snmp = 1;
 			agentx = optarg;
 			break;
@@ -1391,11 +1421,17 @@ lldpd_main(int argc, char *argv[], char *envp[])
 #endif
 			break;
                 case 'S':
-			free(descr_override);
+			if (descr_override) {
+				fprintf(stderr, "-S can only be used once\n");
+				usage();
+			}
                         descr_override = strdup(optarg);
                         break;
 		case 'P':
-			free(platform_override);
+			if (platform_override) {
+				fprintf(stderr, "-P can only be used once\n");
+				usage();
+			}
 			platform_override = strdup(optarg);
 			break;
 		case 'H':
