@@ -160,6 +160,19 @@ ssize_t lldpctl_recv(lldpctl_conn_t *conn, const uint8_t *data, size_t length);
  */
 ssize_t lldpctl_send(lldpctl_conn_t *conn);
 
+/**
+ * Function invoked to see if there's more data to be processed in the buffer.
+ *
+ * This function should be invoked to check for notifications in the data that
+ * has already been read. Its used typically for asynchronous connections.
+ *
+ * @param  conn  Handle to the connection to lldpd.
+ * @return 0 to indicate maybe more data is available for processing
+ *         !0 to indicate no data or insufficient data for processing
+ */
+int lldpctl_process_conn_buffer(lldpctl_conn_t *conn);
+
+
 /**
  * Allocate a new handler for connecting to lldpd.
  *
@@ -596,6 +609,7 @@ typedef enum {
 	lldpctl_k_config_fast_start_enabled, /**< `(I,WO)` Is fast start enabled */
 	lldpctl_k_config_fast_start_interval, /**< `(I,WO)` Start fast transmit interval */
 	lldpctl_k_config_ifdescr_update, /**< `(I,WO)` Enable or disable setting interface description */
+	lldpctl_k_config_iface_promisc,  /**< `(I,WO)` Enable or disable promiscuous mode on interfaces */
 
 	lldpctl_k_interface_name = 1000, /**< `(S)` The interface name. */
 
