@@ -124,7 +124,7 @@ lldpd_remote_cleanup(struct lldpd_hardware *hardware,
 		port_next = TAILQ_NEXT(port, p_entries);
 		del = all;
 		if (!all && expire &&
-		    (now - port->p_lastupdate >= port->p_chassis->c_ttl)) {
+		    (now >= port->p_lastupdate + port->p_chassis->c_ttl)) {
 			hardware->h_ageout_cnt++;
 			hardware->h_delete_cnt++;
 			del = 1;
@@ -159,8 +159,12 @@ lldpd_port_cleanup(struct lldpd_port *port, int all)
 	lldpd_ppvid_cleanup(port);
 	lldpd_pi_cleanup(port);
 #endif
+	/* will set these to NULL so we don't free wrong memory */
+
 	free(port->p_id);
+	port->p_id = NULL;
 	free(port->p_descr);
+	port->p_descr = NULL;
 	if (all) {
 		free(port->p_lastframe);
 		if (port->p_chassis) { /* chassis may not have been attributed, yet */
@@ -177,6 +181,7 @@ lldpd_config_cleanup(struct lldpd_config *config)
 	free(config->c_mgmt_pattern);
 	free(config->c_cid_pattern);
 	free(config->c_iface_pattern);
+	free(config->c_hostname);
 	free(config->c_platform);
 	free(config->c_description);
 }
