@@ -195,7 +195,7 @@ log_info(const char *token, const char *emsg, ...)
 {
 	va_list	 ap;
 
-	if (debug > 1 || logh) {
+	if (!debug || debug > 1 || logh) {
 		va_start(ap, emsg);
 		vlog(LOG_INFO, token, emsg, ap);
 		va_end(ap);
